tkmilan.diagram
===============

.. automodule:: tkmilan.diagram

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      CircleCenter
      DoubleMultiLine
      EllipseCenter
      Line
      RectangleCenter
      SquareCenter
      VectorH
      VectorPolar
      VectorV
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      A
      C
      Cap
      D
      Diagram
      DiagramElement
      DiagramElementMultiple
      DiagramElementSingle
      Ellipse
      GeometryLine
      Join
      MultiLine
      Polygon
      Rectangle
      Smooth
      SmoothAlgorithm
      Text
      Vector
      XY
   
   

   
   
   



